==> zio-aws-networkmanager_3-5.17.116.2-sources.jar: zio/aws/networkmanager/model/DisassociateTransitGatewayConnectPeerResponse.scala <==
package zio.aws.networkmanager.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class DisassociateTransitGatewayConnectPeerResponse(
    transitGatewayConnectPeerAssociation: Option[
      zio.aws.networkmanager.model.TransitGatewayConnectPeerAssociation
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.networkmanager.model.DisassociateTransitGatewayConnectPeerResponse = {
    import DisassociateTransitGatewayConnectPeerResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.networkmanager.model.DisassociateTransitGatewayConnectPeerResponse
      .builder()
      .optionallyWith(
        transitGatewayConnectPeerAssociation.map(value => value.buildAwsValue())
      )(_.transitGatewayConnectPeerAssociation)
      .build()
  }
  def asReadOnly
      : zio.aws.networkmanager.model.DisassociateTransitGatewayConnectPeerResponse.ReadOnly =
    zio.aws.networkmanager.model.DisassociateTransitGatewayConnectPeerResponse
      .wrap(buildAwsValue())
}
object DisassociateTransitGatewayConnectPeerResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.networkmanager.model.DisassociateTransitGatewayConnectPeerResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.networkmanager.model.DisassociateTransitGatewayConnectPeerResponse =
      zio.aws.networkmanager.model
        .DisassociateTransitGatewayConnectPeerResponse(
          transitGatewayConnectPeerAssociation.map(value => value.asEditable)
        )
    def transitGatewayConnectPeerAssociation: Option[
      zio.aws.networkmanager.model.TransitGatewayConnectPeerAssociation.ReadOnly
    ]
    def getTransitGatewayConnectPeerAssociation: ZIO[
      Any,
      AwsError,
      zio.aws.networkmanager.model.TransitGatewayConnectPeerAssociation.ReadOnly
    ] = AwsError.unwrapOptionField(
      "transitGatewayConnectPeerAssociation",
      transitGatewayConnectPeerAssociation
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.networkmanager.model.DisassociateTransitGatewayConnectPeerResponse
  ) extends zio.aws.networkmanager.model.DisassociateTransitGatewayConnectPeerResponse.ReadOnly {
    override val transitGatewayConnectPeerAssociation: Option[
      zio.aws.networkmanager.model.TransitGatewayConnectPeerAssociation.ReadOnly
    ] = scala
      .Option(impl.transitGatewayConnectPeerAssociation())
      .map(value =>
        zio.aws.networkmanager.model.TransitGatewayConnectPeerAssociation
          .wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.networkmanager.model.DisassociateTransitGatewayConnectPeerResponse
  ): zio.aws.networkmanager.model.DisassociateTransitGatewayConnectPeerResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-networkmanager_3-6.20.61.1-sources.jar: zio/aws/networkmanager/model/DisassociateTransitGatewayConnectPeerResponse.scala <==
package zio.aws.networkmanager.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class DisassociateTransitGatewayConnectPeerResponse(
    transitGatewayConnectPeerAssociation: Optional[
      zio.aws.networkmanager.model.TransitGatewayConnectPeerAssociation
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.networkmanager.model.DisassociateTransitGatewayConnectPeerResponse = {
    import DisassociateTransitGatewayConnectPeerResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.networkmanager.model.DisassociateTransitGatewayConnectPeerResponse
      .builder()
      .optionallyWith(
        transitGatewayConnectPeerAssociation.map(value => value.buildAwsValue())
      )(_.transitGatewayConnectPeerAssociation)
      .build()
  }
  def asReadOnly
      : zio.aws.networkmanager.model.DisassociateTransitGatewayConnectPeerResponse.ReadOnly =
    zio.aws.networkmanager.model.DisassociateTransitGatewayConnectPeerResponse
      .wrap(buildAwsValue())
}
object DisassociateTransitGatewayConnectPeerResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.networkmanager.model.DisassociateTransitGatewayConnectPeerResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.networkmanager.model.DisassociateTransitGatewayConnectPeerResponse =
      zio.aws.networkmanager.model
        .DisassociateTransitGatewayConnectPeerResponse(
          transitGatewayConnectPeerAssociation.map(value => value.asEditable)
        )
    def transitGatewayConnectPeerAssociation: Optional[
      zio.aws.networkmanager.model.TransitGatewayConnectPeerAssociation.ReadOnly
    ]
    def getTransitGatewayConnectPeerAssociation: ZIO[
      Any,
      AwsError,
      zio.aws.networkmanager.model.TransitGatewayConnectPeerAssociation.ReadOnly
    ] = AwsError.unwrapOptionField(
      "transitGatewayConnectPeerAssociation",
      transitGatewayConnectPeerAssociation
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.networkmanager.model.DisassociateTransitGatewayConnectPeerResponse
  ) extends zio.aws.networkmanager.model.DisassociateTransitGatewayConnectPeerResponse.ReadOnly {
    override val transitGatewayConnectPeerAssociation: Optional[
      zio.aws.networkmanager.model.TransitGatewayConnectPeerAssociation.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.transitGatewayConnectPeerAssociation())
      .map(value =>
        zio.aws.networkmanager.model.TransitGatewayConnectPeerAssociation
          .wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.networkmanager.model.DisassociateTransitGatewayConnectPeerResponse
  ): zio.aws.networkmanager.model.DisassociateTransitGatewayConnectPeerResponse.ReadOnly =
    new Wrapper(impl)
}
